@@ -12,17 +12,36 @@
 process.env.NODE_ENV = process.env.NODE_ENV || 'development';
 const cluster = require('cluster');
 const http = require('http');
-const http2 = require('spdy');
+//const http2 = require('spdy');
 const fs = require('fs');
 const application = require('./server-app');
 var logger = require('./server-logger');
 const watcher = require('./server-watcher');
-const manifest = require('./../core/manifest');
+// const manifest = require('./../core/manifest');
 const config = require(process.cwd() + '/config/config');
 const work_dir = process.cwd();
 logger = logger.logger;
 
+
+
 exports.serve = function (nylon_path, port) {
+
+    var nylon = {
+        logger: logger,
+        config: config,
+      //  manifest: manifest,
+        work_dir: work_dir,
+        nylon_path: nylon_path,
+        server_port: port,
+        
+        req:{
+            
+        },
+        res:{
+
+        }
+    };
+
     if (cluster.isMaster) {
 
         cluster.fork();
@@ -34,17 +53,21 @@ exports.serve = function (nylon_path, port) {
         watcher.addWatcher(process.cwd() + '/app');
         watcher.addWatcher(process.cwd() + '/config');
         watcher.addWatcher(process.cwd() + '/ssl');
-        watcher.addWatcher(nylon_path + '/java');
-        watcher.addWatcher(nylon_path + '/lib');
+        watcher.addWatcher(nylon.nylon_path + '/java');
+        watcher.addWatcher(nylon.nylon_path + '/lib');
 
     } else {
 
-        var app = application(nylon_path);
+        nylon.server_key = fs.readFileSync(nylon.work_dir + "/ssl/server.key");
+        nylon.server_cert = fs.readFileSync(nylon.work_dir + "/ssl/server.crt");
+
+        var app = application(nylon);
         var server = null;
 
+
         var options = {
-            key: fs.readFileSync(work_dir + "/ssl/server.key"),
-            cert: fs.readFileSync(work_dir + "/ssl/server.crt"),
+            key: nylon.server_key, //fs.readFileSync(work_dir + "/ssl/server.key"),
+            cert: nylon.server_cert, // fs.readFileSync(work_dir + "/ssl/server.crt"),
             spdy: {
                 protocols: ['h2', 'spdy/3.1', 'spdy/3', 'spdy/2', 'http/1.1', 'http/1.0'],
                 plain: false,
@@ -55,14 +78,17 @@ exports.serve = function (nylon_path, port) {
                 }
             }
         };
-        server = http2.createServer(options, app);
 
 
-        server.listen(port, function (error) {
+     //    server = http2.createServer(options, app);
+        server = http.createServer(app);
+
+
+        server.listen(nylon.server_port, function (error) {
             if (error) {
                 logger.error(error);
             } else {
-                logger.info('Nylon server listening on port ' + port + ' pid ' + process.pid);
+                logger.info('Nylon server listening on port ' + nylon.server_port + ' pid ' + process.pid);
             }
         });
 
